Change log
==========

`Next version`_
~~~~~~~~~~~~~~~

`0.4`_ (2019-06-13)
~~~~~~~~~~~~~~~~~~~

- Added a middleware which allows whitelisting IP networks.
- Dropped Python 2 compatibility.


`0.3`_ (2018-09-12)
~~~~~~~~~~~~~~~~~~~

- Added Django 2.1 to the build matrix.
- Reformatted the Python code using black.
- Basic authorization: Fail earlier if there are no credentials.


`0.2`_ (2018-04-06)
~~~~~~~~~~~~~~~~~~~

- Renamed the project to django-curtains, and added a basic
  authorization-using middleware.


`0.1`_ (2018-02-26)
~~~~~~~~~~~~~~~~~~~

- Initial public version.

.. _0.1: https://github.com/matthiask/django-curtains/commit/89bb93c5cdba
.. _0.2: https://github.com/matthiask/django-curtains/compare/0.1...0.2
.. _0.3: https://github.com/matthiask/django-curtains/compare/0.2...0.3
.. _0.4: https://github.com/matthiask/django-curtains/compare/0.3...0.4
.. _Next version: https://github.com/matthiask/django-curtains/compare/0.4...master
